@@ -1,4 +1,4 @@
-use crate::time::{Date, DateTime, DateOptTime};
+use crate::time::{DateTime, DateOptTime};
 
 pub mod table;
 
@@ -12,10 +12,6 @@ pub fn format_date<T>(date: T) -> String where T: Into<DateOptTime> {
     }.to_string()
 }
 
-pub fn format_period(period: (Date, Date)) -> String {
-    format!("{} - {}", format_date(period.0), format_date(period.1.pred()))
-}
-
 pub fn untitle(string: &str) -> String {
     let mut result = String::with_capacity(string.len());
 
