@@ -1,8 +1,6 @@
 use std::collections::HashMap;
 
-#[cfg(test)] use chrono::NaiveDate;
 #[cfg(test)] use indoc::indoc;
-use chrono::{DateTime, TimeZone};
 use log::error;
 #[cfg(test)] use mockito::{self, Mock, mock};
 use reqwest::Url;
@@ -16,9 +14,17 @@ use crate::time;
 use crate::util::{self, DecimalRestrictions};
 
 use super::{QuotesMap, QuotesProvider};
+use super::common::{send_request, is_outdated_time};
+
+#[derive(Deserialize)]
+#[serde(deny_unknown_fields)]
+pub struct AlphaVantageConfig {
+    api_key: String,
+}
 
 pub struct AlphaVantage {
     api_key: String,
+    client: Client,
 }
 
 impl AlphaVantage {
@@ -26,9 +32,10 @@ impl AlphaVantage {
     // quotes API which makes it unusable for stocks now, but maybe will be useful for forex quotes
     // in the future.
     #[allow(dead_code)]
-    pub fn new(token: &str) -> AlphaVantage {
+    pub fn new(config: &AlphaVantageConfig) -> AlphaVantage {
         AlphaVantage {
-            api_key: token.to_owned(),
+            api_key: config.api_key.clone(),
+            client: Client::new(),
         }
     }
 }
@@ -52,18 +59,10 @@ impl QuotesProvider for AlphaVantage {
             ("apikey", self.api_key.as_ref()),
         ])?;
 
-        let get = |url| -> GenericResult<HashMap<String, Cash>> {
-            let response = Client::new().get(url).send()?;
-            if !response.status().is_success() {
-                return Err!("The server returned an error: {}", response.status());
-            }
-
+        Ok(send_request(&self.client, &url).and_then(|response| {
             Ok(parse_quotes(response).map_err(|e| format!(
                 "Quotes info parsing error: {}", e))?)
-        };
-
-        Ok(get(url.as_str()).map_err(|e| format!(
-            "Failed to get quotes from {}: {}", url, e))?)
+        }).map_err(|e| format!("Failed to get quotes from {}: {}", url, e))?)
     }
 }
 
@@ -109,7 +108,7 @@ fn parse_quotes(response: Response) -> GenericResult<HashMap<String, Cash>> {
             continue;
         }
 
-        if is_outdated(time) {
+        if is_outdated_time(time, date_time!(2018, 10, 31, 20, 0, 0)).is_some() {
             outdated.push(quote.symbol);
             continue;
         }
@@ -127,22 +126,20 @@ fn parse_quotes(response: Response) -> GenericResult<HashMap<String, Cash>> {
     Ok(quotes)
 }
 
-#[cfg(not(test))]
-fn is_outdated<T: TimeZone>(time: DateTime<T>) -> bool {
-    super::is_outdated_quote(time)
-}
-
-#[cfg(test)]
-fn is_outdated<T: TimeZone>(time: DateTime<T>) -> bool {
-    time.naive_utc() <= NaiveDate::from_ymd(2018, 10, 31).and_hms(16 + 4, 0, 0)
-}
-
 #[cfg(test)]
 mod tests {
+    use rstest::{rstest, fixture};
     use super::*;
 
-    #[test]
-    fn no_quotes() {
+    #[fixture]
+    fn client() -> AlphaVantage {
+        AlphaVantage::new(&AlphaVantageConfig {
+            api_key: s!("mock")
+        })
+    }
+
+    #[rstest]
+    fn no_quotes(client: AlphaVantage) {
         let _mock = mock_response(
             "/query?function=BATCH_STOCK_QUOTES&symbols=BND%2CBNDX&apikey=mock",
             indoc!(r#"
@@ -156,13 +153,11 @@ mod tests {
                 }
             "#)
         );
-
-        let client = AlphaVantage::new("mock");
         assert_eq!(client.get_quotes(&["BND", "BNDX"]).unwrap(), HashMap::new());
     }
 
-    #[test]
-    fn quotes() {
+    #[rstest]
+    fn quotes(client: AlphaVantage) {
         let _mock = mock_response(
             "/query?function=BATCH_STOCK_QUOTES&symbols=BND%2CBNDX%2COUTDATED%2CINVALID&apikey=mock",
             indoc!(r#"
@@ -196,8 +191,6 @@ mod tests {
             "#)
         );
 
-        let client = AlphaVantage::new("mock");
-
         let mut quotes = HashMap::new();
         quotes.insert(s!("BND"), Cash::new("USD", dec!(77.8650)));
         quotes.insert(s!("BNDX"), Cash::new("USD", dec!(54.5450)));
