@@ -2,9 +2,8 @@ use std::collections::HashMap;
 use std::sync::Mutex;
 use std::time::Duration;
 
-use chrono::{DateTime, NaiveDateTime, Utc};
 #[cfg(test)] use indoc::indoc;
-use log::{debug, trace};
+use log::debug;
 #[cfg(test)] use mockito::{self, Mock, mock};
 use rayon::prelude::*;
 use reqwest::Url;
@@ -20,6 +19,13 @@ use crate::util::{self, DecimalRestrictions};
 use crate::types::Decimal;
 
 use super::{QuotesMap, QuotesProvider};
+use super::common::{send_request, is_outdated_unix_time};
+
+#[derive(Deserialize)]
+#[serde(deny_unknown_fields)]
+pub struct FinnhubConfig {
+    token: String,
+}
 
 pub struct Finnhub {
     token: String,
@@ -28,9 +34,9 @@ pub struct Finnhub {
 }
 
 impl Finnhub {
-    pub fn new(token: &str) -> Finnhub {
+    pub fn new(config: &FinnhubConfig) -> Finnhub {
         Finnhub {
-            token: token.to_owned(),
+            token: config.token.clone(),
             client: Client::new(),
             rate_limiter: RateLimiter::new()
                 .with_limit(60 / 2, Duration::from_secs(60))
@@ -56,8 +62,7 @@ impl Finnhub {
             _ => return Ok(None),
         };
 
-        if is_outdated(time)? {
-            let time = DateTime::<Utc>::from_utc(NaiveDateTime::from_timestamp(time, 0), Utc);
+        if let Some(time) = is_outdated_unix_time(time, 1582295300)? {
             debug!("{}: Got outdated quotes: {}.", symbol, time);
             return Ok(None);
         }
@@ -97,15 +102,7 @@ impl Finnhub {
         let get = |url| -> GenericResult<Option<T>> {
             self.rate_limiter.wait(&format!("request to {}", url));
 
-            trace!("Sending request to {}...", url);
-            let response = self.client.get(url).send()?;
-            trace!("Got response from {}.", url);
-
-            if !response.status().is_success() {
-                return Err!("Server returned an error: {}", response.status());
-            }
-            let reply = response.text()?;
-
+            let reply = send_request(&self.client, url)?.text()?;
             if reply.trim() == "Symbol not supported" {
                 return Ok(None);
             }
@@ -113,8 +110,7 @@ impl Finnhub {
             Ok(serde_json::from_str(&reply)?)
         };
 
-        Ok(get(url.as_str()).map_err(|e| format!(
-            "Failed to get quotes from {}: {}", url, e))?)
+        Ok(get(&url).map_err(|e| format!("Failed to get quotes from {}: {}", url, e))?)
     }
 }
 
@@ -151,26 +147,21 @@ impl QuotesProvider for Finnhub {
     }
 }
 
-#[cfg(not(test))]
-fn is_outdated(time: i64) -> GenericResult<bool> {
-    let date_time = NaiveDateTime::from_timestamp_opt(time, 0).ok_or_else(|| format!(
-        "Got an invalid UNIX time: {}", time))?;
-    Ok(super::is_outdated_quote::<Utc>(DateTime::from_utc(date_time, Utc)))
-}
-
-#[cfg(test)]
-#[allow(clippy::unnecessary_wraps)]
-fn is_outdated(time: i64) -> GenericResult<bool> {
-    #![allow(clippy::unreadable_literal)]
-    Ok(time < 1582295400)
-}
-
 #[cfg(test)]
 mod tests {
+    use rstest::{rstest, fixture};
     use super::*;
 
-    #[test]
-    fn quotes() {
+    #[fixture]
+    fn client() -> Finnhub {
+        Finnhub::new(&FinnhubConfig {
+            token: s!("mock")
+        })
+    }
+
+
+    #[rstest]
+    fn quotes(client: Finnhub) {
         let _bnd_profile_mock = mock_response("/api/v1/stock/profile2?symbol=BND&token=mock", indoc!(r#"
             {
                 "country": "US",
@@ -221,7 +212,7 @@ mod tests {
                 "l": 2088,
                 "o": 2142.14990234375,
                 "pc": 2153.10009765625,
-                "t": 1
+                "t": 1582295300
             }
         "#));
 
@@ -269,8 +260,6 @@ mod tests {
             }
         "#));
 
-        let client = Finnhub::new("mock");
-
         let mut quotes = HashMap::new();
         quotes.insert(s!("BND"), Cash::new("USD", dec!(85.80000305175781)));
         quotes.insert(s!("FXRL.ME"), Cash::new("RUB", dec!(2758.5)));
