@@ -329,10 +329,16 @@ impl<'a> TradesProcessor<'a> {
 
                 "Покупка"
             },
+
             StockSourceDetails::CorporateAction => {
                 self.non_trade_sources = true;
                 "Корп. действие"
             },
+
+            StockSourceDetails::Grant => {
+                self.non_trade_sources = true;
+                "Грант"
+            },
         };
 
         if let Some(ref deductible) = trade.long_term_ownership_deductible {
